Class: RemoteDevJobs::Launch

Inherits:
Object
  • Object
show all
Defined in:
lib/remote_dev_jobs/Launch.rb

Defined Under Namespace

Classes: AuthenticScraper, FlexJobsScraper, StackScraper, WeWorkRemotelyScraper

Class Method Summary collapse

Class Method Details

.logoObject



4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
# File 'lib/remote_dev_jobs/Launch.rb', line 4

def self.
  puts "\e[32m$%$%$%  $%$%$%  $%      %$    $%   $%$%$%  $%$%$%"
  puts "\e[32m%    %  %        $%    %$    %   %   $%    $     "
  puts "\e[32m$$%$%$  $%$%$%    %$  $%    $    $   %$    %$%$%$"
  puts "\e[32m%    %  %       %  $%    $  %    %   $%    $     "
  puts "\e[32m$    $  $       %        %   $  $    %$    %     "
  puts "\e[32m%    %  %$%$%$  $        $    %$     $%    $$%$%$"
  puts ""
  puts "\e[32m       $%$%$%   $%    $%$%$%  $%$%$%             "
  puts "\e[32m         $%    %  %   $%   $  %                  "
  puts "\e[32m         $%   $    $  $$%$%$  $%$%$%             "
  puts "\e[32m         %$   %    %  $%   %       $             "
  puts "\e[32m         $%   %   $   $%   $       %             "
  puts "\e[32m      $%%$%     %$    %$%$%$  %$%$%$             "               
end

.search_optionsObject



20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
# File 'lib/remote_dev_jobs/Launch.rb', line 20

def self.search_options
  3.times do puts '' end
  self.
  2.times do puts "" end
  puts "\e[0mHello and welcome to Remote Jobs! We help you to find remote web"
  puts "development positions, with seniority level when possible."
  puts ""
  puts "To begin, please select the jobs site you would like to search"
  puts "by selecting the number of the site in the following list:"
  puts "(If you would like to exit, please type exit.)"
  puts ""
  puts "\e[32m1.\e[37m Stack Overflow Careers (Seniority level shown)"
  puts "\e[32m2.\e[37m Authentic Jobs"
  puts "\e[32m3.\e[37m We Work Remotely (100% Remote Jobs)"
  puts "\e[32m4.\e[37m FlexJobs (Entry-level focus, company name requires login)"
end


44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/remote_dev_jobs/Launch.rb', line 44

def self.sitemenu
  input = 'X'
  while input != 'exit'
    input = STDIN.gets.chomp
    if input == '1'
      wait_message
      RemoteDevJobs::CLI.new.run(StackScraper)
      search_options
    elsif input == '2'
      wait_message
      RemoteDevJobs::CLI.new.run(AuthenticScraper)
      search_options
    elsif input == '3'
      wait_message
      RemoteDevJobs::CLI.new.run(WeWorkRemotelyScraper)
      search_options
    elsif input == '4'
      wait_message
      RemoteDevJobs::CLI.new.run(FlexJobsScraper)
      search_options
    elsif input == 'exit'
      'do nothing'
    end
  end
end

.wait_messageObject



37
38
39
40
# File 'lib/remote_dev_jobs/Launch.rb', line 37

def self.wait_message
  puts "Searching the site... this will take a moment."
  puts "Thank you for your patience."
end